#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.features.footer.interfaces import IDefaultFooterRendererSettings, IDefaultFooterMenu
from pyams_form.interfaces.form import IInnerSubForm
from pyams_portal.interfaces import MANAGE_TEMPLATE_PERMISSION
from pyams_skin.layer import IPyAMSLayer

# import packages
from pyams_content.features.footer.zmi import FooterSettingsRendererSettingsEditForm
from pyams_content.features.menu.zmi import LinksTable, MenuLinksView, IMenuLinksView
from pyams_utils.adapter import adapter_config
from pyams_zmi.form import InnerAdminEditForm
from z3c.form import field

from onf_website import _


@adapter_config(name='default-footer-properties',
                context=(IDefaultFooterRendererSettings, IPyAMSLayer, FooterSettingsRendererSettingsEditForm),
                provides=IInnerSubForm)
class DefaultFooterPropertiesEditForm(InnerAdminEditForm):
    """Default footer properties edit form"""

    legend = None

    fields = field.Fields(IDefaultFooterRendererSettings)
    edit_permission = MANAGE_TEMPLATE_PERMISSION

    weight = 1


#
# Social links table view
#

class SocialLinksAssociationsTable(LinksTable):
    """Default footer social links associations table"""

    associations_name = 'social'


@adapter_config(name='default-footer-social-links',
                context=(IDefaultFooterRendererSettings, IPyAMSLayer, FooterSettingsRendererSettingsEditForm),
                provides=IInnerSubForm)
@adapter_config(name='++ass++social', context=(IDefaultFooterMenu, IPyAMSLayer),
                provides=IMenuLinksView)
class DefaultFooterSocialLinksView(MenuLinksView):
    """Default footer social links view"""

    title = _("Social networks links")

    table_class = SocialLinksAssociationsTable
    weight = 11


#
# Sites links table view
#

class SitesLinksAssociationsTable(LinksTable):
    """Default footer sites links associations table"""

    associations_name = 'sites'


@adapter_config(name='default-footer-sites-links',
                context=(IDefaultFooterRendererSettings, IPyAMSLayer, FooterSettingsRendererSettingsEditForm),
                provides=IInnerSubForm)
@adapter_config(name='++ass++sites', context=(IDefaultFooterMenu, IPyAMSLayer),
                provides=IMenuLinksView)
class DefaultFooterSitesLinksView(MenuLinksView):
    """Default footer sites links view"""

    title = _("Sites links")

    table_class = SitesLinksAssociationsTable
    weight = 12


#
# Resources links table view
#

class ResourcesLinksAssociationsTable(LinksTable):
    """Default footer resources links associations table"""

    associations_name = 'resources'


@adapter_config(name='default-footer-resources-links',
                context=(IDefaultFooterRendererSettings, IPyAMSLayer, FooterSettingsRendererSettingsEditForm),
                provides=IInnerSubForm)
@adapter_config(name='++ass++resources', context=(IDefaultFooterMenu, IPyAMSLayer),
                provides=IMenuLinksView)
class DefaultFooterResourcesLinksView(MenuLinksView):
    """Default footer resources links view"""

    title = _("Resources links")

    table_class = ResourcesLinksAssociationsTable
    weight = 13


#
# Contacts links table view
#

class ContactsLinksAssociationsTable(LinksTable):
    """Default footer contacts links associations table"""

    associations_name = 'contacts'


@adapter_config(name='default-footer-contacts-links',
                context=(IDefaultFooterRendererSettings, IPyAMSLayer, FooterSettingsRendererSettingsEditForm),
                provides=IInnerSubForm)
@adapter_config(name='++ass++contacts', context=(IDefaultFooterMenu, IPyAMSLayer),
                provides=IMenuLinksView)
class DefaultFooterContactsLinksView(MenuLinksView):
    """Default footer contacts links view"""

    title = _("Contacts links")

    table_class = ContactsLinksAssociationsTable
    weight = 14


#
# Applications links table view
#

class AppsLinksAssociationsTable(LinksTable):
    """Default footer applications links associations table"""

    associations_name = 'apps'


@adapter_config(name='default-footer-apps-links',
                context=(IDefaultFooterRendererSettings, IPyAMSLayer, FooterSettingsRendererSettingsEditForm),
                provides=IInnerSubForm)
@adapter_config(name='++ass++apps', context=(IDefaultFooterMenu, IPyAMSLayer),
                provides=IMenuLinksView)
class DefaultFooterAppsLinksView(MenuLinksView):
    """Default footer apps links view"""

    title = _("Applications links")

    table_class = AppsLinksAssociationsTable
    weight = 15


#
# Legal links table view
#

class LegalLinksAssociationsTable(LinksTable):
    """Default footer legal links associations table"""

    associations_name = 'legal'


@adapter_config(name='default-footer-legal-links',
                context=(IDefaultFooterRendererSettings, IPyAMSLayer, FooterSettingsRendererSettingsEditForm),
                provides=IInnerSubForm)
@adapter_config(name='++ass++legal', context=(IDefaultFooterMenu, IPyAMSLayer),
                provides=IMenuLinksView)
class DefaultFooterLegalLinksView(MenuLinksView):
    """Default footer legal links view"""

    title = _("Legal mentions links")

    table_class = LegalLinksAssociationsTable
    weight = 16
